==> fltk-docs-1.3.5-3-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a7d2e5eb9247b1927ba5cc26dc82acaf3",
"Fl__Multiline__Input_8H_source.html",
"classFl__Browser.html#aedeec78b5054172ffcd79340c0d8f184",
"classFl__FLTK__File__Chooser.html#a44d6cbaeb50a4ec44c6f839d7b0b95bf",
"classFl__Graphics__Driver.html",
"classFl__Image.html#a149cf9b29d743fdd6adb4dd441e9095d",
"classFl__Native__File__Chooser.html#adcfb1c4830c3883c602343d2cfc44a73",
"classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df",
"classFl__Slider.html#aea633a4c884aa5c3627c25a36e69c103",
"classFl__Text__Buffer.html#a11241a972d065c3914ce6645216511d2",
"classFl__Text__Display.html#ad3e3eddb22f3ac494f3702038a17c088",
"classFl__Tree.html#afe5a719a25bcd0b24aef7030d3e06757",
"classFl__Value__Input.html#ae1bea28ce34eea5829ffec809a1a8ff1",
"classFl__Wizard.html#a4a8c03714a5998e8fd1def71e228bbff",
"fl__ask_8H.html#af2427850080f7b2ddc65f9a0f1e2067cacc279f31a556db7999ea30d507084a09",
"glut.html#glut_class_hierarchy",
"group__fl__drawings.html#ga6f6f1aea3b90a03c1714336e7aef349d",
"group__fl__unicode.html#ga7b2d28413204e9059f02f4651f455fb5",
"structFl__Glut__Bitmap__Font.html#a20040fcf6c80074bca31cc698dcf260a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> fltk-docs-1.3.6-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.3.6", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a9edbfd236c9ea348dcaae935a76bd885",
"Fl__Printer_8H.html",
"classFl__Browser__.html#a4d59d5c7d78393a7a5d5bfaa01694580",
"classFl__FLTK__File__Chooser.html#af31ba0b3afe6257b7ed246bf321fb8cd",
"classFl__Graphics__Driver.html#a534f2ce7e973705cb934f6e6304d3636",
"classFl__Input__.html#a23997fbc020994386594fbc6bb7a6548",
"classFl__Paged__Device.html#ab91583935e45f9f85b7abf79c2bcda81",
"classFl__Preferences_1_1Node.html#a37b1824545019d748cf00672861cc1dc",
"classFl__Sys__Menu__Bar.html#ade5c2840df6c3b4b564c09018ff6dc0d",
"classFl__Text__Buffer.html#aa429406d9ae922379a89519cda8b82b5",
"classFl__Tiled__Image.html#a9d22f2345513330c2d21d11bb75f2087",
"classFl__Tree__Item.html#a9e72a148688f46df8e87793510043032",
"classFl__Widget.html#a7f05e24d343941328fa38958feab4168",
"editor.html#editor_replace_dialog",
"forms.html#forms_using",
"group__fl__attributes.html#ga5c8dfa051e445cff49726b256b9f1ca0",
"group__fl__drawings.html#gaf98789ec460134ffc81f2af2d2db6857",
"group__group__comdlg.html#gad14c8bab4536ccb1ee8258bcd0f9ff1e",
"structFl__Menu__Item.html#a996db6347b53fc0ea8ab6ae763a44a2c"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
